#!/usr/bin/env python
# -*- coding: utf-8 -*-

import pygtk
import gtk
import gconf
import os, os.path

DefaultTimePeriod = 1

class Preference(object):
    """Show preference menu, and allow make changes to config"""       
    def __init__(self, applet = None, path = './'):
        """Drow Preference windows and current preferences"""
        self.applet = applet
        builder = gtk.Builder()
        self.glade = os.path.join(path, 'preference.glade')
        builder.add_from_file(self.glade)
        builder.connect_signals(
                { "on_preference_close" : self.destroy,
                "on_Exit_clicked" : self.destroy, 
                "on_Ok_clicked" : self.save_config}
                )
        self.window = builder.get_object("preference")
        self.RefreshSpinButton = builder.get_object("RefreshSpinButton")
        self.Adj = gtk.SpinButton.get_adjustment(self.RefreshSpinButton)
        
        #read config file
        if self.applet == None:
            self.conf = Config(None)
        else:
            self.conf = Config(self.applet)
        (self.TimePeriod) = self.conf.get_settings()
        self.Adj.set_value(self.TimePeriod)
        #show preference windows
        self.window.show()
        
    def get_config(self):
        """Read current config"""
        self.conf.get_settings()

    def save_config(self, *arg):
        """Saved new config"""
        self.NewTimePeriod = int(gtk.Adjustment.get_value(gtk.SpinButton.get_adjustment(self.RefreshSpinButton)))
        self.conf.set_settings(self.NewTimePeriod)
    
    def destroy(self, *arg):
        """Closed windows"""
        #print arg
        self.window.destroy()


class Config():
    """Save all config in GConf"""
    def __init__(self, applet = None, cb_TimePeriod = None):
        """Init variables"""
        self.applet = applet
        self.client = gconf.client_get_default()

        self.client.add_dir(
        "/apps/panel/applets/ubuntu-tips-applet", gconf.CLIENT_PRELOAD_NONE) #delete for applet
        self.prefs_key="/apps/panel/applets/ubuntu-tips-applet"            #delete for applet
#        else:
#            self.prefs_key = self.applet.get_preferences_key()

        if self.prefs_key == None:
            self.client.add_dir(
            "/apps/panel/applets/ubuntu-tips-applet", gconf.CLIENT_PRELOAD_NONE)
            self.prefs_key="/apps/panel/applets/ubuntu-tips-applet"

        self.get_settings()
        self.notify_cb(cb_TimePeriod)
        
    def get_settings(self):
        """Return all settings"""
        self.TimePeriod = self.client.get_int(self.prefs_key + "/TimePeriod")

        if self.TimePeriod == None or self.TimePeriod == 0:
            self.client.set_int(self.prefs_key + "/TimePeriod", DefaultTimePeriod)
            self.TimePeriod = DefaultTimePeriod

        return self.TimePeriod
    
    def set_settings(self, TimePeriod):
        """Saved settings"""
        self.client.set_int(self.prefs_key + "/TimePeriod", TimePeriod)

    def notify_cb(self,cb_TimePeriod):
        """Callback for config changed"""
        if cb_TimePeriod == None:
            cb_TimePeriod = lambda client, cnxn_id, entry, params: None

        self.client.notify_add(self.prefs_key + "/TimePeriod", cb_TimePeriod)
            
        
if __name__ == "__main__":
    app = Preference()
    gtk.main()

