#!/usr/bin/env python
# -*- coding: utf-8 -*-
# UbuntuTips applet for GNOME
#
# Shows some tips with fortunes-ubuntu-server package using Notify
# 2011 (c) Alexandr Gudulin <alexandr@gudulin.ru>
#

import pygtk
import sys
import gtk
import appindicator
import gnome.ui
import os, os.path
import datetime
import gobject
import Preference
from UbuntuTips import UbuntuTips
from commands import *
import gconf
import pynotify

__path__ = '/usr/share/ubuntu-tips-applet'  #work
#__path__ = '/home/sagod/workspace/python/UbuntuTips_Applet_0.1.1' #test

__title__ = 'Ubuntu Tips Applet'
__description__ = 'Applet shows some tips with fortunes-ubuntu-server package using notify'
__version__ = '0.1.2'
__license__ = 'GNU General Public License v.3'
__author__ = 'Alexandr Gudulin <alexandr@gudulin.ru>'


class UbuntuTipsIndicator(object):
    """Ubuntu Tips class, contains the menu builder and head methods"""
    def __init__(self):
        self.indicator = appindicator.Indicator("example-simple-client", "indicator-messages", appindicator.CATEGORY_APPLICATION_STATUS)
        self.indicator.set_status (appindicator.STATUS_ACTIVE)
        self.indicator.set_attention_icon(__path__+'/ubuntutips-panel.svg')
        self.indicator.set_icon(__path__+'/ubuntutips-panel.svg')
        
        # create a Preference object
        self.conf = Preference.Config(self.indicator, self.cb_TimePeriod)
        (self.TimePeriod) = self.conf.get_settings()
        self.time = self.TimePeriod*60
        if self.time == 0:
            self.time = 60
        
        # create a menu
        self.menu = gtk.Menu()

        # create items for the menu - 'Show single tip', 'Disable/Enable', 'Preferences', 'About'
        itemTip = gtk.MenuItem("Show one tip")
        itemTip.connect("activate", self.show_tip)
        itemTip.show()
        self.menu.append(itemTip)
        
        self.itemActivate = gtk.CheckMenuItem("Disable auto refresh")
        self.itemActivate.set_active(False)
        self.itemActivate.show()
        self.menu.append(self.itemActivate)
        
        separator = gtk.SeparatorMenuItem()
        separator.show()
        self.menu.append(separator)

        itemPref = gtk.MenuItem("Preferences...")
        itemPref.connect("activate", self.PreferenceWidget)
        itemPref.show()
        self.menu.append(itemPref)

        itemAbout = gtk.MenuItem("About...")
        itemAbout.connect("activate", self.AboutWidget)
        itemAbout.show()
        self.menu.append(itemAbout)

        separator = gtk.SeparatorMenuItem()
        separator.show()      
        self.menu.append(separator)

        image = gtk.MenuItem("Quit")
        image.connect("activate", self.quit)
        image.show()
        self.menu.append(image)
     
        self.menu.show()
        self.indicator.set_menu(self.menu)
        
        # run after init
        self.after_init()
        
    def after_init(self, *arg):
        """Connect UbuntuTips class and calls timer if Checkbox is disable"""
        self.path = __path__
        self.tips_conf = UbuntuTips(self.conf, self.path)
        self.timer()
        
    def isDisable(self, *arg):
        """Returns the Checkbox status"""
        data = self.itemActivate.get_active()
        return data

    def quit(self, widget, data=None):
        """Closes the main widget"""
        gtk.main_quit()
        
    def next_tip(self):
        """Show next tip if Checkbox is disable"""
        self.tip = getoutput('/usr/bin/ubuntu-server-tip')
        self.tips_conf.show_notify(self.tip)
                    
    def timer_handler(self):
        """Timer handler"""
        if True == self.isDisable():
            return False
        self.next_tip()
        self.start_timer = datetime.datetime.today()
        return True
        
    def timer(self):
        """Shows next tip after the time period"""
        self.TimePeriod = self.conf.get_settings()
        self.time = self.TimePeriod*60
        self.source_event = gobject.timeout_add_seconds(self.time, self.timer_handler)
        self.start_timer = datetime.datetime.today()
                
    def show_tip(self, *arg):
        """Shows a tip without waiting timer handler"""
        gobject.source_remove(self.source_event)
        self.next_tip()
        self.timer()
        
    def cb_TimePeriod(self,client, cnxn_id, entry, params):
        """Run after changed Time Period"""
        gobject.source_remove(self.source_event)
        self.timer()
        self.TimePeriod = self.conf.get_settings()

    def PreferenceWidget(self, *arg):
        """Creates the Preference object - calls the Preference widget"""
        self.path = __path__
        self.pref = Preference.Preference(self.indicator, self.path)
        
    def AboutWidget(self, *arg):
        """Calls About widget with author's settings"""
        self.about_path = __path__ + '/ubuntutips-logo.png'
        self.about_pixbuf = gtk.gdk.pixbuf_new_from_file(self.about_path)

        gnome.ui.About(__title__, __version__, __license__,
                       __description__,
                       [__author__,],
                        None,
                        None,
                        self.about_pixbuf,
                       ).show()

if __name__ == '__main__':
    indicator = UbuntuTipsIndicator()
    gtk.main()
